##  Updating Multiple Fact Sheets in Bulk
By switching to table view mode in the inventory, you can add or update data across multiple fact sheets in one go. Table view displays fact sheets in a tabular format, with fact sheets as rows and their attributes as columns. You can add or edit data directly in the table, similar to how you would in a spreadsheet. For a detailed guide, see [Bulk Updating Data in Inventory Table View](https://help.sap.com/docs/leanix/ea/bulk-updating-data-in-inventory-table-view?locale=en-US&state=PRODUCTION&version=CLOUD "Table View lets you view and edit multiple fact sheets in a spreadsheet-like format—perfect for scanning, comparing, and updating data quickly and efficiently.").
You can also efficiently add, update, and remove data in fact sheets through an Excel file. For a detailed guide, see [Importing Fact Sheet Data Through Excel File](https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US "https://help.sap.com/docs/leanix/ea/importing-fact-sheet-data-through-excel-file?locale=en-US").
